@@ -1,10 +1,11 @@
-skip_if_not_or_load_if_installed("lavaan")
+skip_if_not_installed("lavaan")
+
 structure <- " ind60 =~ x1 + x2 + x3
   dem60 =~ y1 + y2 + y3
   dem60 ~ ind60 "
 
 set.seed(123)
-model <- lavaan::sem(structure, data = PoliticalDemocracy)
+model <- lavaan::sem(structure, data = lavaan::PoliticalDemocracy)
 
 # Specific reports
 test_that("model-lavaan detailed report", {
